ConnectFailure class

Constructors

ConnectFailure({required int tabId, String? reason})
ConnectFailure.fromJson(List jsonList)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
reason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabId int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() List<Object?>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

type → const String