DebugStateChange class

Constructors

DebugStateChange({required int tabId, required String newState, String? reason})
DebugStateChange.fromJson(List jsonList)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
newState String
Can only be startDebugging or stopDebugging.
final
reason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabId int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() List<Object?>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

failedToConnect → const String
startDebugging → const String
stopDebugging → const String
type → const String