DebugInfo class

Constructors

DebugInfo({String? appEntrypointPath, String? appId, String? appInstanceId, String? appOrigin, String? appUrl, String? authUrl, String? dwdsVersion, String? extensionUrl, bool? isInternalBuild, bool? isFlutterApp, String? workspaceName, String? tabUrl, int? tabId})
const
DebugInfo.fromJson(List list)
factory

Properties

appEntrypointPath String?
final
appId String?
final
appInstanceId String?
final
appOrigin String?
final
appUrl String?
final
authUrl String?
final
dwdsVersion String?
final
extensionUrl String?
final
hashCode int
The hash code for this object.
no setteroverride
isFlutterApp bool?
final
isInternalBuild bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabId int?
final
tabUrl String?
final
workspaceName String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() List<Object?>
Mimics built_value serialization for compatibility.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

type → const String