tabUrl property

String? tabUrl
final

Belongs to the tab that requests the DevTools.

Defines the tab being debugged for the debug service that connects to chrome via the extension debugger. Can be null for local debug service, which finds the tab with the correct dartAppInstanceId automatically.

Implementation

final String? tabUrl;