DevToolsResponse class

A response to a DevToolsRequest.

Constructors

DevToolsResponse({required bool success, required bool promptExtension, String? error})
DevToolsResponse.fromJson(List jsonList)
factory

Properties

error String?
final
hashCode int
The hash code for this object.
no setteroverride
promptExtension bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() List<Object?>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

type → const String