BatchedEvents class

A batched group of events, currently always Debugger.scriptParsed

Constructors

BatchedEvents({required List<ExtensionEvent> events})
BatchedEvents.fromJson(List jsonList)
factory

Properties

events List<ExtensionEvent>
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() List<Object?>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

type → const String