ExtensionRequest class

A request to run a command in the Dart Debug Extension.

Constructors

ExtensionRequest({required int id, required String command, String? commandParams})
ExtensionRequest.fromJson(List jsonList)
factory

Properties

command String
final
commandParams String?
Contains JSON-encoded parameters, if available.
final
hashCode int
The hash code for this object.
no setteroverride
id int
Used to associate a request with an ExtensionResponse.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() List<Object?>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

type → const String