ExtensionResponse class

A response to an ExtensionRequest.

Constructors

ExtensionResponse({required int id, required bool success, required String result, String? error})
ExtensionResponse.fromJson(List jsonList)
factory

Properties

error String?
Contains an error, if available.
final
hashCode int
The hash code for this object.
no setteroverride
id int
Used to associate a response with an ExtensionRequest.
final
result String
Contains a JSON-encoded payload.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() List<Object?>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

type → const String