LoadStrategy class abstract

Implementers

Constructors

LoadStrategy(AssetReader _assetReader, {String? packageConfigPath})

Properties

buildSettings → BuildSettings
App build settings, such as entry point, build flags, app kind etc.
no setter
dartRuntimeDebugger → DartRuntimeDebugger
Provides a runtime debugger for the Dart runtime.
no setter
handler → Handler
A handler for strategy specific requests.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
The ID for this strategy.
no setter
libraryRoot → String?
The relative root path for library paths. The current directory will be used if this is not overridden.
no setter
loadLibrariesModule → String
Module containing code for loading libraries.
no setter
loadModuleSnippet → String
Returns a snippet of JS code that can be used to load a JS module.
no setter
moduleFormat → String
Module format for JS generated by the compiler.
no setter
packageConfigLoader → Future<Uint8List?> Function(Uri uri)?
Returns a loader to read the content of the package configuration.
no setter
packageConfigPath → String
The absolute path to the app's package configuration.
no setter
reloadConfiguration → ReloadConfiguration
The reload configuration for this strategy, e.g. liveReload.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bootstrapFor(String entrypoint) → Future<String>
Returns the bootstrap required for this LoadStrategy.
createProvider(String entrypoint, AssetReader reader) → MetadataProvider
Creates and returns a MetadataProvider with the given entrypoint and reader.
g3RelativePath(String absolutePath) → String?
Returns the relative path in google3, determined by the absolutePath.
loadClientSnippet(String clientScript) → String
JS code snippet for loading the injected client script.
metadataProviderFor(String entrypoint) → MetadataProvider
Returns the MetadataProvider for the application located at the provided entrypoint.
moduleForServerPath(String entrypoint, String serverPath) → Future<String?>
Returns the module for the corresponding server path.
moduleInfoForEntrypoint(String entrypoint) → Future<Map<String, ModuleInfo>>
Returns a map from module id to module info for the provided entrypoint.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reinitializeProviderAfterHotReload(String entrypoint, Map<String, List> reloadedModulesToLibraries) → Future<ModifiedModuleReport>
serverPathForAppUri(String appUri) → String?
Returns the server path for the app uri.
serverPathForModule(String entrypoint, String module) → Future<String?>
Returns the server path for the provided module.
sourceMapPathForModule(String entrypoint, String module) → Future<String?>
Returns the source map path for the provided module.
toString() → String
A string representation of this object.
inherited
trackEntrypoint(String entrypoint) → Future<void>
Initializes a MetadataProvider for the application located at the provided entrypoint.

Operators

operator ==(Object other) → bool
The equality operator.
inherited