utilities library

Functions

invalidVariableName(String keyword, {bool strictMode = true}) → bool
Returns true for invalid JS variable names, such as keywords. Also handles invalid variable names in strict mode, like "arguments".
pathToJSIdentifier(String path) → String
Transforms a path to a valid JS identifier.
toJSIdentifier(String name) → String
Escape name to make it into a valid identifier.