DevToolsRequest class
A request to open DevTools.
Constructors
- DevToolsRequest({required String appId, required String instanceId, int? contextId, String? tabUrl, bool? uriOnly, String? client})
- DevToolsRequest.fromJson(List jsonList)
-
factory
Properties
- appId → String
-
Identifies a given application, across tabs/windows.
final
- client → String?
-
Identifies the client that DWDS is attaching to.
final
- contextId → int?
-
Identifies the context in which evaluations should occur.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- instanceId → String
-
Identifies a given instance of an application, unique per tab/window.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tabUrl → String?
-
Belongs to the tab that requests the DevTools.
final
- uriOnly → bool?
-
Designates this as a request to send back the DevTools URI instead of
opening DevTools in a new tab or window.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → List< Object?> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override