DebugSettings class
Debug settings for the connected app.
These are set by the code runner and passed to DWDS on start up.
Constructors
- DebugSettings({bool enableDebugging = true, bool enableDebugExtension = false, bool useSseForDebugProxy = true, bool useSseForDebugBackend = true, bool useSseForInjectedClient = true, @Deprecated('Use ddsConfiguration instead.') bool spawnDds = true, @Deprecated('Use ddsConfiguration instead.') int? ddsPort, bool enableDevToolsLaunch = true, bool launchDevToolsInNewWindow = true, bool emitDebugEvents = true, @Deprecated('Use ddsConfigurationInstead. DevTools will eventually only be ' 'served via DDS.') DevToolsLauncher? devToolsLauncher, ExpressionCompiler? expressionCompiler, UrlEncoder? urlEncoder, DartDevelopmentServiceConfiguration ddsConfiguration = const DartDevelopmentServiceConfiguration()})
-
const
Properties
- ddsConfiguration → DartDevelopmentServiceConfiguration
-
final
- ddsPort → int?
-
final
- devToolsLauncher → DevToolsLauncher?
-
final
- emitDebugEvents → bool
-
final
- enableDebugExtension → bool
-
final
- enableDebugging → bool
-
final
- enableDevToolsLaunch → bool
-
final
- expressionCompiler → ExpressionCompiler?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- launchDevToolsInNewWindow → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spawnDds → bool
-
final
- urlEncoder → UrlEncoder?
-
final
- useSseForDebugBackend → bool
-
final
- useSseForDebugProxy → bool
-
final
- useSseForInjectedClient → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited