ToolConfiguration class
Configuration about the app, debug settings, and file system.
This is set by the code runner and passed to DWDS on start up.
Constructors
- ToolConfiguration({required LoadStrategy loadStrategy, required DebugSettings debugSettings, required AppMetadata appMetadata})
-
const
Properties
- appMetadata → AppMetadata
-
final
- debugSettings → DebugSettings
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loadStrategy → LoadStrategy
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited